@@ -1,8 +1,11 @@
 /* This file is part of the yazpp toolkit.
- * Copyright (C) 1998-2010 Index Data and Mike Taylor
+ * Copyright (C) 1998-2011 Index Data and Mike Taylor
  * See the file LICENSE for details.
  */
 
+#if HAVE_CONFIG_H
+#include <config.h>
+#endif
 #ifdef WIN32
 #define USE_THREADS 1
 #endif
