@@ -1,3 +1,6 @@
+#if HAVE_CONFIG_H
+#include <config.h>
+#endif
 #include <stdlib.h>
 
 #include <yazpp/pdu-assoc.h>
